@@ -24,7 +24,8 @@ Znuny.Agent.MentionAction = (function (TargetNS) {
 
         $('.MentionRow').each(function() {
             $(this).on('click', function() {
-                Data.UserID = $(this).attr('id');
+                Data.MentionedUserID = $(this).attr('data-user-id');
+
                 Core.AJAX.FunctionCall(
                     Core.Config.Get('Baselink'),
                     Data,
